@@ -4,7 +4,7 @@ import logging
 import requests
 
 from ..const import RESPONSE_OK
-from ..programme import Programme
+from ..classes.programme import Programme
 
 from .const_gb import CHANNEL_IMAGE_URL, PVR_IMAGE_URL, SCHEDULE_URL, LIVE_IMAGE_URL
 
@@ -14,12 +14,10 @@ _LOGGER = logging.getLogger(__name__)
 class SkyQCountry:
     """UK specific SkyQ."""
 
-    def __init__(self, host):
+    def __init__(self):
         """Initialise UK remote."""
         self.channel_image_url = CHANNEL_IMAGE_URL
         self.pvr_image_url = PVR_IMAGE_URL
-        self._host = host
-        self.country = "GBR"
 
     def getEpgData(self, sid, channelno, epgDate):
         """Get EPG data for UK."""
